@@ -89,7 +89,7 @@ def DownloadIPFS_Binary(downloading_callback=None):
             from urllib import request
             request.urlretrieve(ipfs_url, ipfs_zip_path)
             with tarfile.open(ipfs_zip_path, "r:gz") as tar:
-                tar.extractall()
+                safe_tar_extract(tar)
 
             result = RunCommand("go-ipfs/install.sh")
             if "cannot install" in result and "ipfs" in os.listdir("go-ipfs"):
@@ -379,3 +379,25 @@ def CheckPeerConnection(id, name=""):
     if not contact:
         contact = IPFS_LNS.AddContact(id, name)
     return contact.CheckConnection()
+
+
+def safe_tar_extract(tar, path=".", members=None, *, numeric_owner=False):
+    """
+    Security patch to replace the tar.extractall function,
+    by TrellixVulnTeam to fix the CVE-2007-4559 'bug'.
+    """
+    def is_within_directory(directory, target):
+
+        abs_directory = os.path.abspath(directory)
+        abs_target = os.path.abspath(target)
+
+        prefix = os.path.commonprefix([abs_directory, abs_target])
+
+        return prefix == abs_directory
+
+    for member in tar.getmembers():
+        member_path = os.path.join(path, member.name)
+        if not is_within_directory(path, member_path):
+            raise Exception("Attempted Path Traversal in Tar File")
+
+    tar.extractall(path, members, numeric_owner=numeric_owner)
